@@ -3,10 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         Scripts/condor/cleanupjob.sh
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -26,37 +26,32 @@
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-if [ $# -ne 1 ] ; then
-   echo usage: $0 jobWorkingDirectory
+if [ $# -ne 3 ] ; then
+   echo usage: $0 jobWorkingDirectory jobScratchDirectory jobClass
    exit 64
 fi
 
-cd $1
-exitStatus=$?
+jobWorkingDirectory=$1
+jobScratchDirectory=$2
+jobClass=$3
 
-if [ $exitStatus -eq 0 ] ; then
-   . /etc/environ.sh
-   use -e -r pegasus-@PEGASUSVERSION@
-
-   if [ -d work/pegasus ] ; then
-      propertiesFile=$(ls work/pegasus/pegasus.[1-9]*.properties 2> /dev/null)
-      if [ -n "${propertiesFile}" ] ; then
-         pegasus-analyzer --dir=work/pegasus \
-                          --conf=${propertiesFile} > pegasus.analysis 2>&1
-
-         pegasus-statistics --conf=${propertiesFile} \
-                            --statistics-level=jb_stats \
-                            --quiet \
-                            work/pegasus
-         if [ -f work/pegasus/statistics/jobs.csv ] ; then
-            mv work/pegasus/statistics/jobs.csv pegasusjobstats.csv
-         fi
-         if [ -f work/pegasus/statistics/jobs.txt ] ; then
-            mv work/pegasus/statistics/jobs.txt pegasusjobstats.txt
-         fi
+exitStatus=0
+if [ ${jobClass} = PEGASUS ] ; then
+   if [ ${jobScratchDirectory} != ${jobWorkingDirectory} ] ; then
+      rm -rf ${jobScratchDirectory}
+      exitStatus=$?
+   else
+      rm -rf ${jobScratchDirectory}/scratch
+      if [ $? -eq 0 ] ; then
+         rm -rf ${jobScratchDirectory}/work
+         exitStatus=$?
+      else
+         exitStatus=$?
       fi
-      rm -rf scratch
    fi
+else
+   rm -rf ${jobWorkingDirectory}
+   exitStatus=$?
 fi
 
-exit $exitStatus
+exit ${exitStatus}
