@@ -3,11 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         Scripts/pbs/receiveinput.sh
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
-# All rights reserved.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -27,29 +26,36 @@
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-if [ $# -ne 2 ] ; then
-   echo usage: $0 jobWorkingDirectory transferredTimestampFile
+if [ $# -ne 3 ] ; then
+   echo usage: $0 jobWorkingDirectory jobScratchDirectory transferredTimestampFile
    exit 64
 fi
 
-rm -rf $1
-mkdir $1
+jobWorkingDirectory=$1
+jobScratchDirectory=$2
+transferredTimestampFile=$3
+
+rm -rf ${jobWorkingDirectory}
+mkdir ${jobWorkingDirectory}
 exitStatus=$?
 
-if [ $exitStatus -eq 0 ] ; then
-   cd $1
+if [ ${exitStatus} -eq 0 ] ; then
+   cd ${jobWorkingDirectory}
    exitStatus=$?
 
-   if [ $exitStatus -eq 0 ] ; then
+   if [ ${exitStatus} -eq 0 ] ; then
       tar xvzf -
       exitStatus=$?
 
-      touch .__fileTimeMarker
-      sleep 1
-
-      date +"%s" > $2
+      if [ ${exitStatus} -eq 0 ] ; then
+         touch .__fileTimeMarker
+         sleep 1
+         date +"%s" > ${transferredTimestampFile}
+      fi
    fi
+
+   mkdir -p ${jobScratchDirectory}
+   exitStatus=$?
 fi
 
-exit $exitStatus
-
+exit ${exitStatus}
